@@ -2,8 +2,8 @@
 import inspect
 from typing import List
 
-from .models import UserPagination, User
 from .grpc_client import AccountServiceGRPCClient
+from .models import UserPagination, User
 
 __all__ = [
     'init_service',
@@ -42,5 +42,5 @@ def get_user_list(id_list: list) -> List[User]:
 
 @_param_check
 def get_user_page_list(current_page: int = 1, page_size: int = 10, username: str = '',
-                       phone: str = '', email: str = '') -> UserPagination:
-    return _client.get_user_page_list(current_page, page_size, username, phone, email)
+                       phone: str = '', email: str = '', name: str = '') -> UserPagination:
+    return _client.get_user_page_list(current_page, page_size, username, phone, email, name)
