@@ -4,14 +4,14 @@ from typing import Optional, List
 
 import grpc
 from google.protobuf.any_pb2 import Any
+from google.protobuf.any_pb2 import Any as pbAny
 
+from . import accountService_pb2 as a_pb
+from . import accountService_pb2_grpc as a_grpc
+from . import common_pb2 as c_pb
 from .models import User, UserPagination, AccountServiceException
 from .schema import UserObjectSchema as UOSch, UserPbSchema as UPSch, UserPaginationObjectSchema as UPOSch, \
     UserPaginationPbSchema as UPPSch
-from . import common_pb2 as c_pb
-from . import accountService_pb2_grpc as a_grpc
-from . import accountService_pb2 as a_pb
-from google.protobuf.any_pb2 import Any as pbAny
 
 
 class AccountServiceGRPCClient:
@@ -54,10 +54,11 @@ class AccountServiceGRPCClient:
             return u_ls
 
     def get_user_page_list(self, current_page: int, page_size: int, username: str = '',
-                           phone: str = '', email: str = '') -> UserPagination:
+                           phone: str = '', email: str = '', name: str = '') -> UserPagination:
         with self._stub() as stub:
             resp = stub.GetUserPageList(self._pack(a_pb.GetUserPageListRequest(
-                current_page=current_page, page_size=page_size, username=username, phone=phone, email=email)))
+                current_page=current_page, page_size=page_size, username=username, phone=phone, email=email, name=name
+            )))
             up_pb = self._unpack(resp, a_pb.GetUserPageListResponse)
             up = UPOSch().load(UPPSch().dump(up_pb))
             return up
